/**
 * Copyright 2014-2015 Kakao Corp.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kakao.auth.callback;

import com.kakao.auth.AuthService.AgeAuthStatus;

public class AccountErrorResult {
    final private AgeAuthStatus status;
    final private String errorMessage;
    final private Exception exception;

    public AccountErrorResult(int statusCode) {
        this.status = AgeAuthStatus.valueOf(statusCode);
        this.errorMessage = "Age Authentication failure";
        this.exception = null;
    }

    public AccountErrorResult(int statusCode, String errorMessage) {
        this.status = AgeAuthStatus.valueOf(statusCode);
        this.errorMessage = errorMessage;
        this.exception = null;
    }

    public AccountErrorResult(int statusCode, String errorMessage, Exception exception) {
        this.status = AgeAuthStatus.valueOf(statusCode);
        this.errorMessage = errorMessage;
        this.exception = exception;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public AgeAuthStatus getStatus() {
        return status;
    }

    public Exception getException() {
        return exception;
    }

    @Override
    public String toString() {
        return "AccountErrorResult{" +
                "status=" + status +
                ", errorMessage='" + errorMessage + '\'' +
                '}';
    }
}
